@@ -4,19 +4,24 @@
 #' 
 #' @param len A numeric vector that contains lengths measurements or a formula of the form \code{len~spec} where \dQuote{len} generically represents the length variable and \dQuote{spec} generically represents the species variable. Note that this formula can only contain two variables and must have the length variable on the left-hand-side and the species variable on the right-hand-side.
 #' @param species A character or factor vector that contains the species names. Ignored if \code{len} is a formula.
+#' @param group A named list that provides specific choices for \code{group} for species for which more than one set of Gabelhouse lengths exists in \code{\link{PSDlit}}.
 #' @param data A data.frame that minimally contains the length measurements and species names if \code{len} is a formula.
 #' @param units A string that indicates the type of units used for the lengths. Choices are \code{mm} for millimeters (DEFAULT), \code{cm} for centimeters, and \code{in} for inches.
 #' @param use.names A logical that indicates whether the vector returned is numeric (\code{=FALSE}) or string (\code{=TRUE}; default) representations of the Gabelhouse lengths. See details.
-#' @param addSpec A character vector of species names for which \code{addLens} will be provided.
-#' @param addLens A numeric vector of lengths that should be used in addition to the Gabelhouse lengths for the species in \code{addSpec}. See examples.
+#' @param as.fact A logical that indicates that the new variable should be returned as a factor (\code{=TRUE}) or not (\code{=FALSE}). Defaults to same as \code{use.names} unless \code{addLens} is not \code{NULL}, in which case it will default to \code{FALSE}. See details.
+#' @param addLens A named list with (possibly named) numeric vectors of lengths that should be used in addition to the Gabelhouse lengths for the species that form the names in the list. See examples.
 #' @param verbose A logical that indicates whether detailed messages about species without Gabelhouse lengths or with no recorded values should be printed or not.
 #' @param \dots Not used.
 #'
-#' @details This computes a vector that contains the Gabelhouse lengths specific to each species for all individuals in an entire data frame. The vector can be appended to an existing data.frame to create a variable that contains the Gabelhouse lengths for each individual. The Gabelhouse length value will be \code{NA} for each individual for which Gabelhouse length definitions do not exist in \code{\link{PSDlit}}. Species names in the data.frame must be the same as those used in \code{\link{PSDlit}}. See the examples for one method for changing species names to something that this function will recognize.
+#' @details This computes a vector that contains the Gabelhouse lengths specific to each species for all individuals in an entire data frame. The vector can be appended to an existing data.frame to create a variable that contains the Gabelhouse lengths for each individual. The Gabelhouse length value will be \code{NA} for each individual for which Gabelhouse length definitions do not exist in \code{\link{PSDlit}}. Species names in the data.frame must be the same as those used in \code{\link{PSDlit}} (i.e., same spelling and capitalization; use \code{psdVal()} to see the list of species).
+#' 
+#' Some species have Gabelhouse lengths for sub-groups (e.g., \dQuote{lentic} vs \dQuote{lotic}). For these species, choose which sub-group to use with \code{group}.
 #' 
 #' Individuals shorter than \dQuote{stock} length will be listed as \code{substock} if \code{use.names=TRUE} or \code{0} if \code{use.names=FALSE}.
 #' 
-#' Additional lengths to be used for a species may be included by giving a vector of species names in \code{addSpec} and a corresponding vector of additional lengths in \code{addLens}. Note, however, that \code{use.names} will be reset to \code{FALSE} if \code{addSpec} and \code{addLens} are specified, as there is no way to order the names for all species when additional lengths are used.
+#' Additional lengths to be used for a species may be included by giving a named list with vectors of additional lengths in \code{addLens}. Note, however, that \code{as.fact} will be reset to \code{FALSE} if \code{addLens} are specified, as there is no way to order the names (i.e., factor levels) for all species when additional lengths are used.
+#' 
+#' See examples and \href{https://fishr-core-team.github.io/FSA/articles/Computing_PSDs.html}{this article} for a demonstration.
 #'
 #' @return A numeric or factor vector that contains the Gabelhouse length categories.
 #' 
@@ -37,50 +42,64 @@
 #' @keywords manip
 #' 
 #' @examples
-#' ## Create random data for three species
-#' # only for repeatability
+#' #===== Create random data for three species
 #' set.seed(345234534)
 #' dbg <- data.frame(species=factor(rep(c("Bluegill"),30)),
 #'                   tl=round(rnorm(30,130,50),0))
-#' dbg$wt <- round(4.23e-06*dbg$tl^3.316+rnorm(30,0,10),1)
 #' dlb <- data.frame(species=factor(rep(c("Largemouth Bass"),30)),
 #'                   tl=round(rnorm(30,350,60),0))
-#' dlb$wt <- round(2.96e-06*dlb$tl^3.273+rnorm(30,0,60),1)
 #' dbt <- data.frame(species=factor(rep(c("Bluefin Tuna"),30)),
 #'                   tl=round(rnorm(30,1900,300),0))
-#' dbt$wt <- round(4.5e-05*dbt$tl^2.8+rnorm(30,0,6000),1)
 #' df <- rbind(dbg,dlb,dbt)
-#' str(df)
 #'
-#' ## Examples (non-dplyr)
-#' # Add variable using category names -- formula notation
-#' df$PSD <- psdAdd(tl~species,data=df)
-#' head(df)
-#' # Add variable using category names -- non-formula notation
-#' df$PSD1 <- psdAdd(df$tl,df$species)
-#' head(df)
-#' # Add variable using length values as names
-#' df$PSD2 <- psdAdd(tl~species,data=df,use.names=FALSE)
-#' head(df)
-#' # Add additional length and name for Bluegill
-#' df$PSD3 <- psdAdd(tl~species,data=df,addSpec="Bluegill",addLens=175)
-#' head(df)
-#' # Add add'l lengths and names for Bluegill and Largemouth Bass from a data.frame
-#' addls <- data.frame(species=c("Bluegill","Largemouth Bass","Largemouth Bass"),
-#'                     lens=c(175,254,356))
-#' df$psd4 <- psdAdd(tl~species,data=df,addSpec=addls$species,addLens=addls$lens)
-#' head(df)
+#' #===== Simple examples
+#' #----- Add variable using category names -- non-formula notation
+#' df$PSD <- psdAdd(df$tl,df$species)
+#' peek(df,n=6)
 #' 
-#' ## All of the above but using dplyr
+#' #----- Add variable using category names -- formula notation
+#' df$PSD1 <- psdAdd(tl~species,data=df)
+#' peek(df,n=6)
+#' 
+#' #----- Add variable using length values as names
+#' #      Also turned off messaging of fish not in PSDlit
+#' df$PSD2 <- psdAdd(tl~species,data=df,use.names=FALSE,verbose=FALSE)
+#' peek(df,n=6)
+#' 
+#' #----- Same as above but using dplyr
 #' if (require(dplyr)) {
 #'   df <- df %>%
-#'     mutate(PSD1A=psdAdd(tl,species)) %>%
-#'     mutate(PSD2A=psdAdd(tl,species,use.names=FALSE)) %>%
-#'     mutate(psd3a=psdAdd(tl,species,addSpec="Bluegill",addLens=175)) %>%
-#'     mutate(psd4a=psdAdd(tl,species,addSpec=addls$species,addLens=addls$lens))
+#'     mutate(PSD1A=psdAdd(tl,species,verbose=FALSE),
+#'            PSD2A=psdAdd(tl,species,use.names=FALSE,verbose=FALSE))
+#'   peek(df,n=6)
 #' }
-#' df
-#'
+#' 
+#' #===== Adding lengths besides the Gabelhouse lengths
+#' #----- Add a "minimum length" for Bluegill
+#' df$PSD3 <- psdAdd(tl~species,data=df,verbose=FALSE,
+#'                   addLens=list("Bluegill"=c("minLen"=175)))
+#' df$PSD3A <- psdAdd(tl~species,data=df,verbose=FALSE,
+#'                    addLens=list("Bluegill"=175))
+#' df$PSD3B <- psdAdd(tl~species,data=df,verbose=FALSE,
+#'                    addLens=list("Bluegill"=c("minLen"=175)),use.names=FALSE)
+#' head(df,n=6)
+#' 
+#' #----- Add add'l lengths and names for Bluegill and Largemouth Bass
+#' df$psd4 <- psdAdd(tl~species,data=df,verbose=FALSE,
+#'                   addLens=list("Bluegill"=175,
+#'                                "Largemouth Bass"=c(254,356)))
+#' peek(df,n=20)
+#' 
+#' #===== Example for a species with sub-groups
+#' dbt <- data.frame(species=factor(rep(c("Brown Trout"),30)),
+#'                   tl=round(rnorm(30,230,50),0))
+#' dlt <- data.frame(species=factor(rep(c("Lake Trout"),30)),
+#'                   tl=round(rnorm(30,550,60),0))
+#' df2 <- rbind(dbt,dlt)
+#' 
+#' df2$psd <- psdAdd(tl~species,data=df2,group=list("Brown Trout"="lentic"))
+#' peek(df2,n=6)
+#' 
 #' @rdname psdAdd
 #' @export
 psdAdd <- function (len,...) {
@@ -89,20 +108,15 @@ psdAdd <- function (len,...) {
 
 #' @rdname psdAdd
 #' @export
-psdAdd.default <- function(len,species,units=c("mm","cm","in"),use.names=TRUE,
-                           addSpec=NULL,addLens=NULL,verbose=TRUE,...) {
+psdAdd.default <- function(len,species,group=NULL,units=c("mm","cm","in"),
+                           use.names=TRUE,
+                           as.fact=ifelse(is.null(addLens),use.names,FALSE),
+                           addLens=NULL,verbose=TRUE,...) {
   ## Some checks
   units <- match.arg(units)
   if (!is.numeric(len)) STOP("'len' must be numeric.")
   if (!inherits(species,c("character","factor")))
     STOP("'species' must be character or factor.")
-  if (!is.null(addSpec)) {
-    if (is.null(addLens)) {
-      WARN("'addSpec' is not NULL when 'addLens' is NULL; made 'addSpec' NULL.")
-      addSpec <- NULL
-    }
-    use.names <- FALSE
-  }
   ## Prepare the PSD literature values data frame
   PSDlit <- FSA::PSDlit
   ##  Find species that have known Gabelhouse lengths
@@ -119,7 +133,8 @@ psdAdd.default <- function(len,species,units=c("mm","cm","in"),use.names=TRUE,
   # data.frame where species is NA and doesn't have Gabelhousee length
   ndata <- data[is.na(data$species) | !data$species %in% GLHSspecs,]
   if (verbose & nrow(ndata)>0)
-    message("No known Gabelhouse (PSD) lengths for: ",unique(ndata$species))
+    MESSAGE("Species in the data with no Gabelhouse (PSD) lengths in `PSDlit`: ",
+            iStrCollapse(unique(ndata$species)),".")
   # data.frame where species have Gabelhouse lengths ... make sure no NAs
   data <- data[data$species %in% GLHSspecs,]
   data <- data[!is.na(data$species),]
@@ -130,11 +145,15 @@ psdAdd.default <- function(len,species,units=c("mm","cm","in"),use.names=TRUE,
     # isolate a data.frame with the current species
     tmpdf <- data[data$species==GLHSspecs[i],]
     # add Gabelhouse lengths ... put in additional lengths if they are provided
-    if (GLHSspecs[i] %in% addSpec)
-      tmpAddLens <- addLens[which(addSpec==GLHSspecs[i])]
+    if (GLHSspecs[i] %in% names(addLens))
+      tmpAddLens <- addLens[[GLHSspecs[i]]]
     else tmpAddLens <- NULL
     # get the Gabelhouse length categories
-    glhse <- psdVal(GLHSspecs[i],units=units,addLens=tmpAddLens)
+    if (!is.null(group)) {
+      if (GLHSspecs[i] %in% names(group)) group <- group[[GLHSspecs[i]]]
+      else group <- NULL
+    }
+    glhse <- psdVal(GLHSspecs[i],group=group,units=units,addLens=tmpAddLens)
     # computes the Gabelhouse length categories and adds to the data frame
     if (all(is.na(tmpdf$len))) {
       if (verbose) message("All values in 'len' were missing for ",GLHSspecs[i])
@@ -147,7 +166,7 @@ psdAdd.default <- function(len,species,units=c("mm","cm","in"),use.names=TRUE,
   ## reorder the data.frame to match original rows
   ndata <- ndata[order(ndata$rownums),]
   ## factor the PSD variable if using category names
-  if (use.names) 
+  if (as.fact)
     ndata$PSD <- factor(ndata$PSD,
                         levels=c("substock","stock","quality",
                                  "preferred","memorable","trophy"))
@@ -157,12 +176,14 @@ psdAdd.default <- function(len,species,units=c("mm","cm","in"),use.names=TRUE,
 
 #' @rdname psdAdd
 #' @export
-psdAdd.formula <- function(len,data=NULL,units=c("mm","cm","in"),use.names=TRUE,
-                           addSpec=NULL,addLens=NULL,verbose=TRUE,...) {
+psdAdd.formula <- function(len,data=NULL,group=NULL,units=c("mm","cm","in"),
+                           use.names=TRUE,
+                           as.fact=ifelse(is.null(addLens),use.names,FALSE),
+                           addLens=NULL,verbose=TRUE,...) {
   ## Perform some checks on the formula
   tmp <- iHndlFormula(len,data,expNumR=1,expNumE=1,expNumENums=0,expNumEFacts=1)
   if (tmp$vnum!=2)
-    STOP("'len' must have one variable on the left-hand-side\n",
+    STOP("'len' must have one variable on the left-hand-side ",
          "and one variable on the right-hand-side.")
   if (!tmp$metExpNumR)
     STOP("'len' must have a left-hand-side with one and only one variable.")
@@ -175,6 +196,6 @@ psdAdd.formula <- function(len,data=NULL,units=c("mm","cm","in"),use.names=TRUE,
     STOP("'len' must have one and only one factor variable (species)",
          " on right-hand-side.")
   ## Send to default method
-  psdAdd.default(tmp$mf[[tmp$Rpos]],tmp$mf[[tmp$EFactPos]],units,
-                 use.names,addSpec,addLens,verbose,...)
+  psdAdd.default(tmp$mf[[tmp$Rpos]],tmp$mf[[tmp$EFactPos]],group,units,
+                 use.names,as.fact,addLens,verbose,...)
 }
