@@ -138,78 +138,133 @@ test_that("chapmanRobson errors and warnings",{
 
 ## Test Output Types ----
 test_that("catchCurve() outpute types",{
-  expect_is(cc,"catchCurve")
+  expect_equal(class(cc),"catchCurve")
   # coef, unweighted
   ccA <- coef(cc)
   expect_true(is.vector(ccA))
-  expect_is(ccA,"numeric")
+  expect_equal(class(ccA),"numeric")
   expect_equal(length(ccA),2)
   expect_equal(names(ccA),c("Z","A"))
   ccA <- coef(cc,parm="Z")
   expect_true(is.vector(ccA))
-  expect_is(ccA,"numeric")
+  expect_equal(class(ccA),"numeric")
   expect_equal(length(ccA),1)
   expect_equal(names(ccA),c("Z"))
   ccA <- coef(cc,parm="lm")
   expect_true(is.vector(ccA))
-  expect_is(ccA,"numeric")
+  expect_equal(class(ccA),"numeric")
   expect_equal(length(ccA),2)
   expect_equal(names(ccA),c("(Intercept)","age.e"))
+  # coef, unweighted with as.df
+  ccA <- coef(cc,as.df=TRUE)
+  expect_true(is.data.frame(ccA))
+  expect_equal(ncol(ccA),2)
+  expect_equal(nrow(ccA),1)
+  expect_equal(names(ccA),c("Z","A"))
+  ccA <- coef(cc,parm="Z",as.df=TRUE)
+  expect_true(is.data.frame(ccA))
+  expect_equal(ncol(ccA),1)
+  expect_equal(nrow(ccA),1)
+  expect_equal(names(ccA),c("Z"))
+  ccA <- coef(cc,parm="lm",as.df=TRUE)
+  expect_true(is.data.frame(ccA))
+  expect_equal(ncol(ccA),2)
+  expect_equal(nrow(ccA),1)
+  expect_equal(names(ccA),c("(Intercept)","age.e"))
   # coef, weighted
   cc2A <- coef(cc2)
   expect_true(is.vector(cc2A))
-  expect_is(cc2A,"numeric")
+  expect_equal(class(cc2A),"numeric")
   expect_equal(length(cc2A),2)
   expect_equal(names(cc2A),c("Z","A"))
   cc2A <- coef(cc2,parm="A")
   expect_true(is.vector(cc2A))
-  expect_is(cc2A,"numeric")
+  expect_equal(class(cc2A),"numeric")
   expect_equal(length(cc2A),1)
   expect_equal(names(cc2A),c("A"))
   cc2A <- coef(cc2,parm="lm")
   expect_true(is.vector(cc2A))
-  expect_is(cc2A,"numeric")
+  expect_equal(class(cc2A),"numeric")
   expect_equal(length(cc2A),2)
   expect_equal(names(cc2A),c("(Intercept)","age.e"))
   # confint, unweighted
   ccA <- confint(cc)
-  expect_is(ccA,"matrix")
+  expect_equal(class(ccA),c("matrix","array"))
   expect_equal(mode(ccA),"numeric")
   expect_equal(nrow(ccA),2)
   expect_equal(ncol(ccA),2)
   expect_equal(rownames(ccA),c("Z","A"))
   expect_equal(colnames(ccA),c("95% LCI","95% UCI"))
   ccA <- confint(cc,parm="Z")
-  expect_is(ccA,"matrix")
+  expect_equal(class(ccA),c("matrix","array"))
   expect_equal(mode(ccA),"numeric")
   expect_equal(nrow(ccA),1)
   expect_equal(ncol(ccA),2)
   expect_equal(rownames(ccA),c("Z"))
   expect_equal(colnames(ccA),c("95% LCI","95% UCI"))
   ccA <- confint(cc,parm="lm")
-  expect_is(ccA,"matrix")
+  expect_equal(class(ccA),c("matrix","array"))
   expect_equal(mode(ccA),"numeric")
   expect_equal(nrow(ccA),2)
   expect_equal(ncol(ccA),2)
   expect_equal(rownames(ccA),c("(Intercept)","age.e"))
   expect_equal(colnames(ccA),c("95% LCI","95% UCI"))
+  # confint, unweighted using incl.est=TRUE
+  ccA <- confint(cc,incl.est=TRUE)
+  expect_equal(class(ccA),c("matrix","array"))
+  expect_equal(mode(ccA),"numeric")
+  expect_equal(nrow(ccA),2)
+  expect_equal(ncol(ccA),3)
+  expect_equal(rownames(ccA),c("Z","A"))
+  expect_equal(colnames(ccA),c("Est","95% LCI","95% UCI"))
+  ccA <- confint(cc,parm="Z",incl.est=TRUE)
+  expect_equal(class(ccA),c("matrix","array"))
+  expect_equal(mode(ccA),"numeric")
+  expect_equal(nrow(ccA),1)
+  expect_equal(ncol(ccA),3)
+  expect_equal(rownames(ccA),c("Z"))
+  expect_equal(colnames(ccA),c("Est","95% LCI","95% UCI"))
+  ccA <- confint(cc,parm="lm",incl.est=TRUE)
+  expect_equal(class(ccA),c("matrix","array"))
+  expect_equal(mode(ccA),"numeric")
+  expect_equal(nrow(ccA),2)
+  expect_equal(ncol(ccA),3)
+  expect_equal(rownames(ccA),c("(Intercept)","age.e"))
+  expect_equal(colnames(ccA),c("Est","95% LCI","95% UCI"))
+  # confint, unweighted using incl.est=TRUE with as.df=TRUE
+  ccA <- confint(cc,incl.est=TRUE,as.df=TRUE)
+  expect_true(is.data.frame(ccA))
+  expect_equal(nrow(ccA),1)
+  expect_equal(ncol(ccA),6)
+  expect_equal(names(ccA),c("Z","Z_LCI","Z_UCI","A","A_LCI","A_UCI"))
+  ccA <- confint(cc,parm="Z",incl.est=TRUE,as.df=TRUE)
+  expect_true(is.data.frame(ccA))
+  expect_equal(nrow(ccA),1)
+  expect_equal(ncol(ccA),3)
+  expect_equal(names(ccA),c("Z","Z_LCI","Z_UCI"))
+  ccA <- confint(cc,parm="lm",incl.est=TRUE,as.df=TRUE)
+  expect_true(is.data.frame(ccA))
+  expect_equal(nrow(ccA),1)
+  expect_equal(ncol(ccA),6)
+  expect_equal(names(ccA),c("(Intercept)","(Intercept)_LCI","(Intercept)_UCI",
+                            "age.e","age.e_LCI","age.e_UCI"))
   # confint, weighted
   cc2A <- confint(cc2)
-  expect_is(cc2A,"matrix")
+  expect_equal(class(cc2A),c("matrix","array"))
   expect_equal(mode(cc2A),"numeric")
   expect_equal(nrow(cc2A),2)
   expect_equal(ncol(cc2A),2)
   expect_equal(rownames(cc2A),c("Z","A"))
   expect_equal(colnames(cc2A),c("95% LCI","95% UCI"))
   cc2A <- confint(cc2,parm="Z")
-  expect_is(cc2A,"matrix")
+  expect_equal(class(cc2A),c("matrix","array"))
   expect_equal(mode(cc2A),"numeric")
   expect_equal(nrow(cc2A),1)
   expect_equal(ncol(cc2A),2)
   expect_equal(rownames(cc2A),c("Z"))
   expect_equal(colnames(cc2A),c("95% LCI","95% UCI"))
   cc2A <- confint(cc2,parm="lm")
-  expect_is(cc2A,"matrix")
+  expect_equal(class(cc2A),c("matrix","array"))
   expect_equal(mode(cc2A),"numeric")
   expect_equal(nrow(cc2A),2)
   expect_equal(ncol(cc2A),2)
@@ -217,21 +272,35 @@ test_that("catchCurve() outpute types",{
   expect_equal(colnames(cc2A),c("95% LCI","95% UCI"))
   # summary
   cc2A <- summary(cc2)
-  expect_is(cc2A,"matrix")
+  expect_equal(class(cc2A),c("matrix","array"))
   expect_equal(mode(cc2A),"numeric")
   expect_equal(nrow(cc2A),2)
   expect_equal(ncol(cc2A),4)
   expect_equal(rownames(cc2A),c("Z","A"))
   expect_equal(colnames(cc2A),c("Estimate","Std. Error","t value","Pr(>|t|)"))
   cc2A <- summary(cc2,parm="Z")
-  expect_is(cc2A,"matrix")
+  expect_equal(class(cc2A),c("matrix","array"))
   expect_equal(mode(cc2A),"numeric")
   expect_equal(nrow(cc2A),1)
   expect_equal(ncol(cc2A),4)
   expect_equal(rownames(cc2A),c("Z"))
   expect_equal(colnames(cc2A),c("Estimate","Std. Error","t value","Pr(>|t|)"))
   cc2A <- summary(cc2,parm="lm")
-  expect_is(cc2A,"summary.lm")
+  expect_equal(class(cc2A),"summary.lm")
+
+  # summary with as.df=TRUE
+  cc2A <- summary(cc2,as.df=TRUE)
+  expect_true(is.data.frame(cc2A))
+  expect_equal(nrow(cc2A),1)
+  expect_equal(ncol(cc2A),4)
+  expect_equal(names(cc2A),c("Z","Z_SE","A","A_SE"))
+  cc2A <- summary(cc2,parm="Z",as.df=TRUE)
+  expect_true(is.data.frame(cc2A))
+  expect_equal(nrow(cc2A),1)
+  expect_equal(ncol(cc2A),2)
+  expect_equal(names(cc2A),c("Z","Z_SE"))
+  cc2A <- summary(cc2,parm="lm",as.df=TRUE)
+  expect_equal(class(cc2A),"summary.lm")
   
   # r-squared
   expect_true(is.numeric(rSquared(cc)))
@@ -242,59 +311,107 @@ test_that("catchCurve() outpute types",{
 })
 
 test_that("chapmanRobson() output types",{
-  expect_is(cr,"chapmanRobson")
+  expect_equal(class(cr),"chapmanRobson")
   # coef
   crA <- coef(cr)
   expect_true(is.vector(crA))
-  expect_is(crA,"numeric")
+  expect_equal(class(crA),"numeric")
   expect_equal(length(crA),2)
   expect_equal(names(crA),c("S","Z"))
   crA <- coef(cr,parm="S")
   expect_true(is.vector(crA))
-  expect_is(crA,"numeric")
+  expect_equal(class(crA),"numeric")
   expect_equal(length(crA),1)
   expect_equal(names(crA),c("S"))
+  # coef with as.df=TRUE
+  crA <- coef(cr,as.df=TRUE)
+  expect_true(is.data.frame(crA))
+  expect_equal(nrow(crA),1)
+  expect_equal(ncol(crA),2)
+  expect_equal(names(crA),c("S","Z"))
+  crA <- coef(cr,parm="S",as.df=TRUE)
+  expect_true(is.data.frame(crA))
+  expect_equal(nrow(crA),1)
+  expect_equal(ncol(crA),1)
+  expect_equal(names(crA),"S")
   # summary
   crA <- summary(cr)
-  expect_is(crA,"matrix")
+  expect_equal(class(crA),c("matrix","array"))
   expect_equal(mode(crA),"numeric")
   expect_equal(nrow(crA),2)
   expect_equal(ncol(crA),2)
   expect_equal(rownames(crA),c("S","Z"))
   expect_equal(colnames(crA),c("Estimate","Std. Error"))
   crA <- summary(cr,parm="S")
-  expect_is(crA,"matrix")
+  expect_equal(class(crA),c("matrix","array"))
   expect_equal(mode(crA),"numeric")
   expect_equal(nrow(crA),1)
   expect_equal(ncol(crA),2)
-  expect_equal(rownames(crA),c("S"))
+  expect_equal(rownames(crA),"S")
   expect_equal(colnames(crA),c("Estimate","Std. Error"))
+  # summary with as.df=TRUE
+  crA <- summary(cr,as.df=TRUE)
+  expect_true(is.data.frame(crA))
+  expect_equal(nrow(crA),1)
+  expect_equal(ncol(crA),4)
+  expect_equal(names(crA),c("S","S_SE","Z","Z_SE"))
+  crA <- summary(cr,parm="S",as.df=TRUE)
+  expect_true(is.data.frame(crA))
+  expect_equal(nrow(crA),1)
+  expect_equal(ncol(crA),2)
+  expect_equal(names(crA),c("S","S_SE"))
   # confint
   crA <- confint(cr)
-  expect_is(crA,"matrix")
+  expect_equal(class(crA),c("matrix","array"))
   expect_equal(mode(crA),"numeric")
   expect_equal(nrow(crA),2)
   expect_equal(ncol(crA),2)
   expect_equal(rownames(crA),c("S","Z"))
   expect_equal(colnames(crA),c("95% LCI","95% UCI"))
   crA <- confint(cr,parm="S")
-  expect_is(crA,"matrix")
+  expect_equal(class(crA),c("matrix","array"))
   expect_equal(mode(crA),"numeric")
   expect_equal(nrow(crA),1)
   expect_equal(ncol(crA),2)
-  expect_equal(rownames(crA),c("S"))
+  expect_equal(rownames(crA),"S")
   expect_equal(colnames(crA),c("95% LCI","95% UCI"))
+  # confint with incl.est=TRUE
+  crA <- confint(cr,incl.est=TRUE)
+  expect_equal(class(crA),c("matrix","array"))
+  expect_equal(mode(crA),"numeric")
+  expect_equal(nrow(crA),2)
+  expect_equal(ncol(crA),3)
+  expect_equal(rownames(crA),c("S","Z"))
+  expect_equal(colnames(crA),c("Est","95% LCI","95% UCI"))
+  crA <- confint(cr,parm="S",incl.est=TRUE)
+  expect_equal(class(crA),c("matrix","array"))
+  expect_equal(mode(crA),"numeric")
+  expect_equal(nrow(crA),1)
+  expect_equal(ncol(crA),3)
+  expect_equal(rownames(crA),"S")
+  expect_equal(colnames(crA),c("Est","95% LCI","95% UCI"))
+  # confint with incl.est=TRUE and as.df=TRUE
+  crA <- confint(cr,incl.est=TRUE,as.df=TRUE)
+  expect_true(is.data.frame(crA))
+  expect_equal(nrow(crA),1)
+  expect_equal(ncol(crA),6)
+  expect_equal(names(crA),c("S","S_LCI","S_UCI","Z","Z_LCI","Z_UCI"))
+  crA <- confint(cr,parm="S",incl.est=TRUE,as.df=TRUE)
+  expect_true(is.data.frame(crA))
+  expect_equal(nrow(crA),1)
+  expect_equal(ncol(crA),3)
+  expect_equal(names(crA),c("S","S_LCI","S_UCI"))
   
-  expect_is(cr1,"chapmanRobson")
+  expect_equal(class(cr1),"chapmanRobson")
   # coef
   crA <- coef(cr1)
   expect_true(is.vector(crA))
-  expect_is(crA,"numeric")
+  expect_equal(class(crA),"numeric")
   expect_equal(length(crA),2)
   expect_equal(names(crA),c("S","Z"))
   # summary
   crA <- summary(cr1)
-  expect_is(crA,"matrix")
+  expect_equal(class(crA),c("matrix","array"))
   expect_equal(mode(crA),"numeric")
   expect_equal(nrow(crA),2)
   expect_equal(ncol(crA),2)
@@ -302,23 +419,23 @@ test_that("chapmanRobson() output types",{
   expect_equal(colnames(crA),c("Estimate","Std. Error"))
   # confint
   crA <- confint(cr1)
-  expect_is(crA,"matrix")
+  expect_equal(class(crA),c("matrix","array"))
   expect_equal(mode(crA),"numeric")
   expect_equal(nrow(crA),2)
   expect_equal(ncol(crA),2)
   expect_equal(rownames(crA),c("S","Z"))
   expect_equal(colnames(crA),c("95% LCI","95% UCI"))
-  expect_is(cr1,"chapmanRobson")
+  expect_equal(class(cr1),"chapmanRobson")
   
   # coef
   crA <- coef(cr2)
   expect_true(is.vector(crA))
-  expect_is(crA,"numeric")
+  expect_equal(class(crA),"numeric")
   expect_equal(length(crA),2)
   expect_equal(names(crA),c("S","Z"))
   # summary
   crA <- summary(cr2)
-  expect_is(crA,"matrix")
+  expect_equal(class(crA),c("matrix","array"))
   expect_equal(mode(crA),"numeric")
   expect_equal(nrow(crA),2)
   expect_equal(ncol(crA),2)
@@ -326,7 +443,7 @@ test_that("chapmanRobson() output types",{
   expect_equal(colnames(crA),c("Estimate","Std. Error"))
   # confint
   crA <- confint(cr2)
-  expect_is(crA,"matrix")
+  expect_equal(class(crA),c("matrix","array"))
   expect_equal(mode(crA),"numeric")
   expect_equal(nrow(crA),2)
   expect_equal(ncol(crA),2)
@@ -373,7 +490,7 @@ test_that("catchCurve() and ChaptmanRobson() does negative ages2use properly.",{
   scc1 <- summary(cc1)
   cc2 <- catchCurve(n~age,data=df,ages2use=-(1:2))
   scc2 <- summary(cc2)  
-  expect_equal(cc1,cc2)
+  expect_equal(cc1,cc2,ignore_attr=TRUE)
   expect_equal(scc1,scc2)
   
   cr1 <- chapmanRobson(n~age,data=df,ages2use=3:10)
@@ -406,37 +523,34 @@ test_that("catchCurve() and chapmanRobson() match Miranda & Bettoli (2007) boxes
 })
 
 test_that("catchCurve() and chapmanRobson() match results from fishmethods package",{
-  if (require(fishmethods)) {
-    ## get data
-    data(rockbass,package="fishmethods")
-    ## fishmethods results
-    fm <- agesurv(age=rockbass$age,full=6)$results
-    ## FSA results
-    df <- data.frame(xtabs(~age,data=rockbass))
-    df$age <- fact2num(df$age)
-    cc1 <- catchCurve(Freq~age,data=df)
-    scc1 <- summary(cc1) 
-    cr1 <- chapmanRobson(Freq~age,data=df,zmethod="original")
-    scr1 <- summary(cr1)
-    cr2 <- chapmanRobson(Freq~age,data=df,zmethod="Smithetal")
-    scr2 <- summary(cr2)    
-    # catchCurve results match
-    expect_equal(round(scc1["Z","Estimate"],3),
-                 round(fm$Estimate[fm$Method=="Linear Regression" & fm$Parameter=="Z"]),3)
-    expect_equal(round(scc1["Z","Std. Error"],3),
-                 round(fm$SE[fm$Method=="Linear Regression" & fm$Parameter=="Z"]),3)
-    # chapmanRobson results match
-    expect_equal(round(scr1["Z","Estimate"],3),
-                 round(fm$Estimate[fm$Method=="Chapman-Robson" & fm$Parameter=="Z"]),3)
-    expect_equal(round(scr1["Z","Std. Error"],3),
-                 round(fm$SE[fm$Method=="Chapman-Robson" & fm$Parameter=="Z"]),3)
-    # chapmanRobson (with Smith et al. (2012) bias corrections)
-    #   results match for the point estimates but not the SE
-    #   fishmethods appears to use eqn 5 from smith et al. for
-    #   the uncorrected SE of Z, whereas FSA uses eqn 2
-    expect_equal(round(scr2["Z","Estimate"],3),
-                 round(fm$Estimate[fm$Method=="Chapman-Robson CB" & fm$Parameter=="Z"]),3)
-    #expect_equal(round(scr2["Z","Std. Error"],3),round(fm$SE[fm$Method=="Chapman-Robson CB" & fm$Parameter=="Z"]),3)
-  }  
+  ## get data
+  data(rockbass,package="fishmethods")
+  ## fishmethods results
+  fm <- fishmethods::agesurv(age=rockbass$age,full=6)$results
+  ## FSA results
+  df <- data.frame(xtabs(~age,data=rockbass))
+  df$age <- fact2num(df$age)
+  cc1 <- catchCurve(Freq~age,data=df)
+  scc1 <- summary(cc1) 
+  cr1 <- chapmanRobson(Freq~age,data=df,zmethod="original")
+  scr1 <- summary(cr1)
+  cr2 <- chapmanRobson(Freq~age,data=df,zmethod="Smithetal")
+  scr2 <- summary(cr2)    
+  # catchCurve results match
+  expect_equal(round(scc1["Z","Estimate"],3),
+               round(fm$Estimate[fm$Method=="Linear Regression" & fm$Parameter=="Z"],3))
+  expect_equal(round(scc1["Z","Std. Error"],3),
+               round(fm$SE[fm$Method=="Linear Regression" & fm$Parameter=="Z"],3))
+  # chapmanRobson results match
+  expect_equal(round(scr1["Z","Estimate"],3),
+               round(fm$Estimate[fm$Method=="Chapman-Robson" & fm$Parameter=="Z"],3))
+  expect_equal(round(scr1["Z","Std. Error"],3),
+               round(fm$SE[fm$Method=="Chapman-Robson" & fm$Parameter=="Z"],3))
+  # chapmanRobson (with Smith et al. (2012) bias corrections)
+  #   results match for the point estimates but not the SE
+  #   fishmethods appears to use eqn 5 from smith et al. for
+  #   the uncorrected SE of Z, whereas FSA uses eqn 2
+  expect_equal(round(scr2["Z","Estimate"],3),
+               round(fm$Estimate[fm$Method=="Chapman-Robson CB" & fm$Parameter=="Z"],3))
+  #expect_equal(round(scr2["Z","Std. Error"],3),round(fm$SE[fm$Method=="Chapman-Robson CB" & fm$Parameter=="Z"]),3)
 })
-
