@@ -1,5 +1,5 @@
 ## Get results for testing ----
-vb1 <- vbFuns()
+vb1 <- suppressWarnings( vbFuns() )
 fit1 <- nls(tl~vb1(age,Linf,K,t0),data=SpotVA1,start=list(Linf=12,K=0.3,t0=0))
 fit3 <- lm(tl~age,data=SpotVA1)
 
